Module ansible — Inmanta 2017.3dev documentation

# Module ansible

> - License: Apache 2.0
> - Version: 0.2.1
> - Upstream project: https://github.com/inmanta/ansible.git

## Entities

entity `ansible::Arg`

  Parents: `std::Entity`

  attribute string `value`=''
  attribute string `name`

  The following implements statements select implementations for this entity:

  > - `std::none`

entity `ansible::JsonArg`

  Parents: `ansible::Arg`

  attribute string `json`

  The following implements statements select implementations for this entity:

  > - `std::none`

entity `ansible::Task`

  Parents: `std::Entity`

  An ansible task

  attribute string `module`

    The ansible module that has to be invoked

  attribute string `host`='localhost'

    The host (target) to execute the task on

  attribute string `name`

    The name of the task. This has to be unique in combination with the host

  attribute string `agent`='ansible'

    The agent that should run the task

  attribute dict `args`

    The args to pass to the task. This dict is directly serialized to json and included varbetim in the playbook

  The following implements statements select implementations for this entity:

  > - `std::none`

## Resources

class `ansible.` `Task`
  - Resource for entity `ansible::Task`
  - Id attribute `name`
  - Agent name `agent`
  - Handlers `ansible.TaskHandler`

## Handlers

class `ansible.` `TaskHandler`
  - Handler name `task`
  - Handler for entity `ansible::Task`